@@ -18,6 +18,7 @@
 import re
 import os
 import sys
+import __builtin__
 import inspect
 import traceback
 
@@ -34,7 +35,7 @@ from sure.registry import context as _registry
 from sure.magic import is_cpython, patchable_builtin
 from sure.terminal import red, green, white, yellow
 
-version = '1.0.5'
+version = '1.0.6'
 
 
 def _get_file_name(func):
@@ -504,7 +505,7 @@ class that(object):
 
         return True
 
-    @property
+    @__builtin__.property
     def is_empty(self):
         try:
             lst = list(self._src)
@@ -517,7 +518,7 @@ class that(object):
         except TypeError:
             raise AssertionError("%r is not iterable" % self._src)
 
-    @property
+    @__builtin__.property
     def are_empty(self):
         return self.is_empty
 
@@ -927,7 +928,7 @@ def assertionmethod(func):
 
 
 def assertionproperty(func):
-    return property(assertionmethod(func))
+    return __builtin__.property(assertionmethod(func))
 
 POSITIVES = [
     'should',
@@ -1000,6 +1001,22 @@ class AssertionBuilder(object):
     def be(self):
         return self
 
+    @assertionproperty
+    def being(self):
+        return self
+
+    @assertionproperty
+    def not_being(self):
+        return self.should_not
+
+    @assertionproperty
+    def not_be(self):
+        return self.obj.should_not
+
+    @assertionproperty
+    def to(self):
+        return self
+
     @assertionproperty
     def when(self):
         return self
@@ -1008,6 +1025,36 @@ class AssertionBuilder(object):
     def have(self):
         return self
 
+    @assertionproperty
+    def with_value(self):
+        return self
+
+    def property(self, name):
+        has_it = hasattr(self.obj, name)
+        if self.negative:
+            assert not has_it, (
+                '%r should not have the property `%s`, '
+                'but it is %r' % (self.obj, name, getattr(self.obj, name)))
+            return True
+
+        assert has_it, (
+            "%r should have the property `%s` but doesn't" % (
+                self.obj, name))
+        return expect(getattr(self.obj, name))
+
+    def key(self, name):
+        has_it = name in self.obj
+        if self.negative:
+            assert not has_it, (
+                '%r should not have the key `%s`, '
+                'but it is %r' % (self.obj, name, self.obj[name]))
+            return True
+
+        assert has_it, (
+            "%r should have the key `%s` but doesn't" % (
+                self.obj, name))
+        return expect(self.obj[name])
+
     @assertionproperty
     def empty(self):
         length = len(self.obj)
@@ -1120,6 +1167,36 @@ class AssertionBuilder(object):
 
     a = an
 
+    @assertionmethod
+    def greater_than(self, dest):
+        if self.negative:
+            msg = u"expected `{0}` to not be greater than `{1}`".format(
+                self.obj, dest)
+
+            assert not self.obj > dest, msg
+
+        else:
+            msg = u"expected `{0}` to be greater than `{1}`".format(
+                self.obj, dest)
+            assert self.obj > dest, msg
+
+        return True
+
+    @assertionmethod
+    def lower_than(self, dest):
+        if self.negative:
+            msg = u"expected `{0}` to not be lower than `{1}`".format(
+                self.obj, dest)
+
+            assert not self.obj < dest, msg
+
+        else:
+            msg = u"expected `{0}` to be lower than `{1}`".format(
+                self.obj, dest)
+            assert self.obj < dest, msg
+
+        return True
+
     @assertionmethod
     def below(self, num):
         if self.negative:
@@ -1154,7 +1231,7 @@ class AssertionBuilder(object):
         self._callable_kw = kw
         return self
 
-    called = property(called_with)
+    called = __builtin__.property(called_with)
 
     @assertionmethod
     def throw(self, *args, **kw):
@@ -1191,9 +1268,12 @@ this = AssertionBuilder('this')
 it = AssertionBuilder('it')
 these = AssertionBuilder('these')
 those = AssertionBuilder('those')
+expect = AssertionBuilder('expect')
 
 
-if is_cpython:
+allows_new_syntax = not os.getenv('SURE_DISABLE_NEW_SYNTAX')
+
+if is_cpython and allows_new_syntax:
 
     def positive_assertion(name, prop=True):
         def method(self):
@@ -1208,7 +1288,7 @@ if is_cpython:
             return instance
 
         method.__name__ = name
-        return (property(method) if prop else method(None))
+        return (__builtin__.property(method) if prop else method(None))
 
     def negative_assertion(name, prop=True):
         def method(self):
@@ -1223,7 +1303,7 @@ if is_cpython:
             return instance
 
         method.__name__ = name
-        return (property(method) if prop else method(None))
+        return (__builtin__.property(method) if prop else method(None))
 
     object_handler = patchable_builtin(object)
 
